0.9.1
-----

- Changed walk() to use UID directly
- Added support for sortCriterion using UID SORT
- Improved test coverage to 80%


0.9.0
-----

- Extracted code from imap-search-scout
- Made API more user-friendly
- Improved test coverage to 79%
